==> gbrainy-0.2.tar.gz: gbrainy-0.2/src/PuzzleCirclesRectangle.cs <==
/*
 * Copyright (C) 2007 Jordi Mas i Hernàndez <jmas@softcatala.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

using System;
using Cairo;
using Mono.Unix;

public class PuzzleCirclesRectangle : Game
{
	public override string Name {
		get {return Catalog.GetString ("Circles in a rectangle");}
	}

	public override string Question {
		get {return Catalog.GetString ("What is the maximum number of circles (as the one showed) that can be feed in the rectangle bellow?");} 
	}

	public override string Tip {
		get { return Catalog.GetString ("You can feed more than 25 circles.");}
	}

	public override void Initialize ()
	{
		right_answer = "27";
	}

	public override void Draw (Cairo.Context gr, int area_width, int area_height)
	{
		double first_x = DrawAreaX + 0.05;
		double first_y = DrawAreaY + 0.1;
		double space_fromrect = 0.02, space_fromcircle = 0.01;
		int circles = 4;

		gr.Scale (area_width, area_height);

		DrawBackground (gr);
		PrepareGC (gr);
		gr.Rectangle (first_x, first_y, 0.5, 0.5);
		gr.Stroke ();

		// |-------|
		gr.MoveTo (first_x, first_y - 0.04 - space_fromrect);
		gr.LineTo (first_x, first_y - space_fromrect);
		gr.Stroke ();
		gr.MoveTo (first_x, first_y - 0.02 - space_fromrect);
		gr.LineTo (first_x + 0.5, first_y - 0.02 - space_fromrect);
		gr.Stroke ();
		gr.MoveTo (first_x + 0.5, first_y - 0.04 - space_fromrect);
		gr.LineTo (first_x + 0.5, first_y - space_fromrect);
		gr.Stroke ();

		gr.MoveTo (first_x + 0.2, first_y - 0.04 - space_fromrect);
		gr.ShowText (Catalog.GetString ("5 units"));
		gr.Stroke ();

		//  ---
		//	 |
		//	 |
		//	 |
		//  ---
		gr.MoveTo (first_x  - space_fromrect, first_y);
		gr.LineTo (first_x  - space_fromrect - 0.04, first_y);
		gr.Stroke ();
		gr.MoveTo (first_x - space_fromrect - 0.02, first_y);
		gr.LineTo (first_x - space_fromrect - 0.02, first_y + 0.5);
		gr.Stroke ();
		gr.MoveTo (first_x - space_fromrect, first_y + 0.5);
		gr.LineTo (first_x - space_fromrect - 0.04, first_y + 0.5);
		gr.Stroke ();

		gr.Save ();
		gr.MoveTo (first_x - space_fromrect - 0.05, first_y + 0.3);
		gr.Rotate (270 * Math.PI/180);
		gr.ShowText (Catalog.GetString ("5 units"));
		gr.Restore ();		
		gr.Stroke ();
		
		// Sample circle
		gr.Arc (first_x + 0.7, first_y + 0.1, 0.1 / 2, 0, 2 * Math.PI);
		gr.Stroke ();

		// |-------|
		gr.MoveTo (first_x + 0.65, first_y + 0.05 - 0.04 - space_fromcircle);
		gr.LineTo (first_x + 0.65, first_y + 0.05 - space_fromcircle);
		gr.Stroke ();
		gr.MoveTo (first_x + 0.65, first_y + 0.05 - 0.02 - space_fromcircle);
		gr.LineTo (first_x + 0.65 + 0.1, first_y + 0.05 - 0.02 - space_fromcircle);
		gr.Stroke ();
		gr.MoveTo (first_x + 0.65 + 0.1, first_y + 0.05 - 0.04 - space_fromcircle);
		gr.LineTo (first_x + 0.65 + 0.1, first_y + 0.05 - space_fromcircle);
		gr.Stroke ();

		gr.MoveTo (first_x + 0.65, first_y - space_fromcircle);
		gr.ShowText (Catalog.GetString ("1 unit"));
		gr.Stroke ();

		//  ---
		//	 |
		//	 |
		//	 |
		//  ---
		gr.MoveTo (first_x + 0.65  - space_fromcircle, first_y + 0.05);
		gr.LineTo (first_x + 0.65  - space_fromcircle - 0.04, first_y + 0.05);
		gr.Stroke ();
		gr.MoveTo (first_x + 0.65 - space_fromcircle - 0.02, first_y + 0.05);
		gr.LineTo (first_x + 0.65 - space_fromcircle - 0.02, first_y  + 0.05 + 0.1);
		gr.Stroke ();
		gr.MoveTo (first_x + 0.65 - space_fromcircle, first_y + 0.1 + 0.05);
		gr.LineTo (first_x + 0.65 - space_fromcircle - 0.04, first_y + 0.1 + 0.05);
		gr.Stroke ();

		gr.Save ();
		gr.MoveTo (first_x + 0.65 - space_fromcircle - 0.05, first_y + 0.15);
		gr.Rotate (270 * Math.PI/180);
		gr.ShowText (Catalog.GetString ("1 unit"));
		gr.Restore ();		
		gr.Stroke ();


		if (DrawAnswer == false)
			return;

		double x;
		for (int line = 0; line < 6; line++)
		{
			for (int circle = 0; circle < circles; circle++) 
			{
				x = first_x + 0.05 + (circle * 0.1);
				
				if (circles == 4)
					x+= 0.05;

				gr.Arc (x, 0.05 + first_y + (0.1 * line) - (0.1/5) * line, 
						0.05 - 0.003, 0, 2 * Math.PI);
				gr.Stroke ();
			}

			if (circles ==5)
				circles = 4;
			else
				circles = 5;
		}

	}
}

==> gbrainy_0.53.orig.tar.gz: gbrainy-0.53/src/PuzzleCirclesRectangle.cs <==
/*
 * Copyright (C) 2007 Jordi Mas i Hernàndez <jmas@softcatala.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

using System;
using Cairo;
using Mono.Unix;

public class PuzzleCirclesRectangle : Game
{
	public override string Name {
		get {return Catalog.GetString ("Circles in a rectangle");}
	}

	public override string Question {
		get {return Catalog.GetString ("What is the maximum number of circles (as the one showed) that can be fit in the square below?");} 
	}

	public override string Tip {
		get { return Catalog.GetString ("You can fit more than 64 circles.");}
	}

	public override string Answer {
		get { 
			string answer = base.Answer + " ";
			answer += String.Format (Catalog.GetString ("In the layout shown {0} units of height are gained in each row. This allows using an additional row."), 0.1340);
			return answer;
		}
	}

	public override void Initialize ()
	{
		right_answer = "68";
	}

	public override void Draw (Cairo.Context gr, int area_width, int area_height)
	{
		double first_x = DrawAreaX + 0.05;
		double first_y = DrawAreaY + 0.1;
		double space_fromrect = 0.02, space_fromcircle = 0.01;
		int circles = 8;
		double unit = 0.0625;

		gr.Scale (area_width, area_height);

		DrawBackground (gr);
		PrepareGC (gr);
		gr.Rectangle (first_x, first_y, unit * 8, unit * 8);
		gr.Stroke ();

		// |-------|
		gr.MoveTo (first_x, first_y - 0.04 - space_fromrect);
		gr.LineTo (first_x, first_y - space_fromrect);
		gr.Stroke ();
		gr.MoveTo (first_x, first_y - 0.02 - space_fromrect);
		gr.LineTo (first_x + 0.5, first_y - 0.02 - space_fromrect);
		gr.Stroke ();
		gr.MoveTo (first_x + 0.5, first_y - 0.04 - space_fromrect);
		gr.LineTo (first_x + 0.5, first_y - space_fromrect);
		gr.Stroke ();

		gr.MoveTo (first_x + 0.2, first_y - 0.04 - space_fromrect);
		gr.ShowText (Catalog.GetString ("8 units"));
		gr.Stroke ();

		//  ---
		//	 |
		//	 |
		//	 |
		//  ---
		gr.MoveTo (first_x  - space_fromrect, first_y);
		gr.LineTo (first_x  - space_fromrect - 0.04, first_y);
		gr.Stroke ();
		gr.MoveTo (first_x - space_fromrect - 0.02, first_y);
		gr.LineTo (first_x - space_fromrect - 0.02, first_y + 0.5);
		gr.Stroke ();
		gr.MoveTo (first_x - space_fromrect, first_y + 0.5);
		gr.LineTo (first_x - space_fromrect - 0.04, first_y + 0.5);
		gr.Stroke ();

		gr.Save ();
		gr.MoveTo (first_x - space_fromrect - 0.05, first_y + 0.3);
		gr.Rotate (270 * Math.PI/180);
		gr.ShowText (Catalog.GetString ("8 units"));
		gr.Restore ();		
		gr.Stroke ();
		
		// Sample circle
		gr.Arc (first_x + 0.7, first_y + 0.1, unit / 2, 0, 2 * Math.PI);
		gr.Stroke ();

		// |-------|
		gr.MoveTo (first_x + 0.65, first_y + 0.05 - 0.04 - space_fromcircle);
		gr.LineTo (first_x + 0.65, first_y + 0.05 - space_fromcircle);
		gr.Stroke ();
		gr.MoveTo (first_x + 0.65, first_y + 0.05 - 0.02 - space_fromcircle);
		gr.LineTo (first_x + 0.65 + 0.1, first_y + 0.05 - 0.02 - space_fromcircle);
		gr.Stroke ();
		gr.MoveTo (first_x + 0.65 + 0.1, first_y + 0.05 - 0.04 - space_fromcircle);
		gr.LineTo (first_x + 0.65 + 0.1, first_y + 0.05 - space_fromcircle);
		gr.Stroke ();

		gr.MoveTo (first_x + 0.65, first_y - space_fromcircle);
		gr.ShowText (Catalog.GetString ("1 unit"));
		gr.Stroke ();

		//  ---
		//	 |
		//	 |
		//	 |
		//  ---
		gr.MoveTo (first_x + 0.65  - space_fromcircle, first_y + 0.05);
		gr.LineTo (first_x + 0.65  - space_fromcircle - 0.04, first_y + 0.05);
		gr.Stroke ();
		gr.MoveTo (first_x + 0.65 - space_fromcircle - 0.02, first_y + 0.05);
		gr.LineTo (first_x + 0.65 - space_fromcircle - 0.02, first_y  + 0.05 + 0.1);
		gr.Stroke ();
		gr.MoveTo (first_x + 0.65 - space_fromcircle, first_y + 0.1 + 0.05);
		gr.LineTo (first_x + 0.65 - space_fromcircle - 0.04, first_y + 0.1 + 0.05);
		gr.Stroke ();

		gr.Save ();
		gr.MoveTo (first_x + 0.65 - space_fromcircle - 0.05, first_y + 0.15);
		gr.Rotate (270 * Math.PI/180);
		gr.ShowText (Catalog.GetString ("1 unit"));
		gr.Restore ();		
		gr.Stroke ();


		if (DrawAnswer == false)
			return;

		double x;
		for (int line = 0; line < 9; line++)
		{
			for (int circle = 0; circle < circles; circle++) 
			{
				x = first_x + (unit / 2) + (circle * unit);
				
				if (circles == 7)
					x+= unit / 2;

				gr.Arc (x, (unit / 2) + first_y + (unit * line) - (unit / 8) * line, 
						(unit / 2), 0, 2 * Math.PI);
				gr.Stroke ();
			}

			if (circles ==8)
				circles = 7;
			else
				circles = 8;
		}

	}
}
